@@ -50,7 +50,7 @@ public:
     const string& getDirection() const override { return direction_; }
 
 protected:
-    void set(LevelSelection&, LevelSelection&, ColourTable&, int) const override;
+    void set(LevelSelection&, LevelSelection&, ColourTable&, int)  override;
     //! Method to print string about this class on to a stream of type ostream (virtual).
     virtual void print(ostream&) const override;
 
